%define rspamd_user       _rspamd
%define rspamd_group      %{rspamd_user}
%define rspamd_home       %{_localstatedir}/lib/rspamd
%define rspamd_logdir     %{_localstatedir}/log/rspamd
%define rspamd_confdir    %{_sysconfdir}/rspamd
%define rspamd_pluginsdir %{_datadir}/rspamd
%define rspamd_rulesdir   %{_datadir}/rspamd/rules
%define rspamd_wwwdir     %{_datadir}/rspamd/www

Name:           rspamd
Version:        3.10.0
Release:        %mkrel 2
Summary:        Rapid spam filtering system
Group:          Networking/Mail

# BSD License (two clause)
# https://www.freebsd.org/copyright/freebsd-license.html
License:        BSD
URL:            https://rspamd.com/
Source0:        https://github.com/rspamd/rspamd/archive/%{version}/%{name}-%{version}.tar.gz
Source1:        rspamd.tmpfile
Source2:        rspamd.logrotate
Source3:        80-rspamd.preset
Patch0:         rspamd-service-type.patch
Patch1:         rspamd-linking.patch
Patch2:         rspamd-default-ciphers.patch
Patch4:         rspamd-system-snowball.patch
BuildRequires:  cmake
BuildRequires:  ragel
BuildRequires:  systemd
BuildRequires:  icu-devel
BuildRequires:  libstemmer-devel
BuildRequires:  pkgconfig(glib-2.0)
BuildRequires:  pkgconfig(jemalloc)
BuildRequires:  pkgconfig(libarchive)
BuildRequires:  pkgconfig(libevent)
BuildRequires:  pkgconfig(openssl)
BuildRequires:  pkgconfig(libpcre2-8)
BuildRequires:  cmake(doctest)
BuildRequires:  pkgconfig(gmime-2.6)
BuildRequires:  pkgconfig(libmagic)
BuildRequires:  pkgconfig(fmt)
BuildRequires:  pkgconfig(libdw)
BuildRequires:  pkgconfig(libdwarf)
%ifarch x86_64
BuildRequires:  pkgconfig(libhs)
%endif
BuildRequires:  pkgconfig(libsodium)
BuildRequires:  pkgconfig(fann)
BuildRequires:  pkgconfig(sqlite3)
BuildRequires:  pkgconfig(luajit)
BuildRequires:  perl(Digest::MD5)
BuildRequires:  pkgconfig(libxxhash)
BuildRequires:  pkgconfig(libzstd)

Requires(pre):  systemd
Requires(post): systemd
Requires(preun): systemd
Requires(postun): systemd
Requires(pre):  shadow-utils
Requires:       logrotate

%description
Rspamd is a rapid, modular and lightweight spam filter. It is designed to work
with big amount of mail and can be easily extended with own filters written in
lua.

%prep
%autosetup -p1

# build with system libs
rm -rf contrib/{doctest,fmt,snowball,xxhash,zstd}

%build
%cmake \
        -DCONFDIR=%{_sysconfdir}/rspamd \
        -DMANDIR=%{_mandir} \
        -DDBDIR=%{_localstatedir}/lib/rspamd \
        -DRUNDIR=%{_rundir}/rspamd \
        -DWANT_SYSTEMD_UNITS=ON \
        -DSYSTEMDDIR=%{_unitdir} \
        -DENABLE_LUAJIT=ON \
        -DLOGDIR=%{_localstatedir}/log/rspamd \
        -DPLUGINSDIR=%{_datadir}/rspamd \
        -DLIBDIR=%{_libdir}/rspamd/ \
        -DINCLUDEDIR=%{_includedir} \
%ifarch x86_64
        -DENABLE_HYPERSCAN=ON \
%endif
        -DENABLE_JEMALLOC=ON \
        -DENABLE_PCRE2=ON \
        -DENABLE_OPTIMIZATION=ON \
        -DENABLE_STATIC=OFF \
        -DNO_SHARED=ON \
        -DDEBIAN_BUILD=1 \
        -DRSPAMD_GROUP=%{rspamd_group} \
        -DRSPAMD_USER=%{rspamd_user} \
        -DSYSTEM_DOCTEST=ON \
        -DSYSTEM_ZSTD=ON \
        -DSYSTEM_FMT=ON \
        -DSYSTEM_XXHASH=ON

%cmake_build

%install
%cmake_install

install -p -D -m 644 %{SOURCE1} %{buildroot}%{_tmpfilesdir}/%{name}.conf
install -d %{buildroot}%{_rundir}/%{name}

install -p -D -m 0644 %{SOURCE3} %{buildroot}%{_presetdir}/80-rspamd.preset

install -p -D -m 0644 %{SOURCE2} %{buildroot}%{_sysconfdir}/logrotate.d/%{name}
install -d -p -m 0755 %{buildroot}%{rspamd_logdir}

install -d -p -m 0755 %{buildroot}%{rspamd_home}
install -p -D -d -m 0755 %{buildroot}%{_sysconfdir}/%{name}/local.d/
install -p -D -d -m 0755 %{buildroot}%{_sysconfdir}/%{name}/override.d/

%pre
%{_sbindir}/groupadd -r %{rspamd_group} 2>/dev/null || :
%{_sbindir}/useradd -g %{rspamd_group} -c "Rspamd user" -s /bin/false -r -d %{rspamd_home} %{rspamd_user} 2>/dev/null || :

%post
%_tmpfilescreate %{name}
# to allow easy upgrade from 0.8.1
chown -R %{rspamd_user}:%{rspamd_group} %{rspamd_home}
# Macro is not used as we want to do this on upgrade
#%%_post_service %%{name}
systemctl --no-reload preset %{name}.service >/dev/null 2>&1 || :
chown %{rspamd_user}:%{rspamd_group} %{rspamd_logdir}

%preun
%_preun_service %{name}

%postun
%_postun_service %{name}

%files
%{_unitdir}/%{name}.service
%{_tmpfilesdir}/%{name}.conf
%dir %ghost %attr(0755, _rspamd, _rspamd) %{_rundir}/%{name}
%ghost %attr(0660, -, -) %{_rundir}/%{name}/%{name}.pid
%{_presetdir}/80-rspamd.preset
%config(noreplace) %{_sysconfdir}/logrotate.d/%{name}
%dir %{rspamd_logdir}
%{_mandir}/man8/%{name}.*
%{_mandir}/man1/rspamc.*
%{_mandir}/man1/rspamadm.*
%{_bindir}/rspamd
%{_bindir}/rspamd_stats
%{_bindir}/rspamc
%{_bindir}/rspamadm
%config(noreplace) %{rspamd_confdir}/%{name}.conf
%config(noreplace) %{rspamd_confdir}/actions.conf
%config(noreplace) %{rspamd_confdir}/composites.conf
%config(noreplace) %{rspamd_confdir}/cgp.inc
%config(noreplace) %{rspamd_confdir}/groups.conf
%config(noreplace) %{rspamd_confdir}/metrics.conf
%config(noreplace) %{rspamd_confdir}/modules.conf
%config(noreplace) %{rspamd_confdir}/statistic.conf
%config(noreplace) %{rspamd_confdir}/settings.conf
%config(noreplace) %{rspamd_confdir}/common.conf
%config(noreplace) %{rspamd_confdir}/lang_detection.inc
%config(noreplace) %{rspamd_confdir}/logging.inc
%config(noreplace) %{rspamd_confdir}/options.inc
%config(noreplace) %{rspamd_confdir}/worker-controller.inc
%config(noreplace) %{rspamd_confdir}/worker-fuzzy.inc
%config(noreplace) %{rspamd_confdir}/worker-normal.inc
%config(noreplace) %{rspamd_confdir}/worker-proxy.inc
%config(noreplace) %{rspamd_confdir}/modules.d/*
%config(noreplace) %{rspamd_confdir}/scores.d/*
%global rspamd_mapsdir %{rspamd_confdir}/maps.d
%config(noreplace) %{rspamd_mapsdir}/dmarc_whitelist.inc
%config(noreplace) %{rspamd_mapsdir}/exe_clickbait.inc
%config(noreplace) %{rspamd_mapsdir}/maillist.inc
%config(noreplace) %{rspamd_mapsdir}/mid.inc
%config(noreplace) %{rspamd_mapsdir}/mime_types.inc
%config(noreplace) %{rspamd_mapsdir}/redirectors.inc
%config(noreplace) %{rspamd_mapsdir}/spf_dkim_whitelist.inc
%config(noreplace) %{rspamd_mapsdir}/surbl-whitelist.inc
%attr(-, _rspamd, _rspamd) %dir %{rspamd_home}
%dir %{rspamd_rulesdir}/controller
%dir %{rspamd_rulesdir}/regexp
%dir %{rspamd_rulesdir}
%dir %{rspamd_confdir}
%dir %{rspamd_confdir}/modules.d
%dir %{rspamd_confdir}/local.d
%dir %{rspamd_confdir}/override.d
%dir %{rspamd_confdir}/scores.d
%dir %{rspamd_pluginsdir}/elastic
%dir %{rspamd_pluginsdir}/languages
%dir %{rspamd_pluginsdir}/lualib
%dir %{rspamd_pluginsdir}
%dir %{rspamd_wwwdir}
%dir %{_libdir}/rspamd
%{rspamd_pluginsdir}/elastic/*.json
%{rspamd_pluginsdir}/languages/*.json
%{rspamd_pluginsdir}/lualib/*.lua
%{rspamd_pluginsdir}/lualib/*/*.lua
%{rspamd_pluginsdir}/*.lua
%{rspamd_rulesdir}/controller/*.lua
%{rspamd_rulesdir}/regexp/*.lua
%{rspamd_rulesdir}/*.lua
%{rspamd_wwwdir}/*
%{_libdir}/rspamd/*
%{rspamd_pluginsdir}/effective_tld_names.dat
%{rspamd_pluginsdir}/languages/stop_words


%changelog
* Sun Jan 12 2025 wally <wally> 3.10.0-2.mga10
+ Revision: 2138408
- rebuild for icu 76.1

* Wed Oct 02 2024 daviddavid <daviddavid> 3.10.0-1.mga10
+ Revision: 2102437
- new version: 3.10.0

* Wed Jun 05 2024 daviddavid <daviddavid> 3.8.4-2.mga10
+ Revision: 2069967
- new version: 3.8.4
- rebuild for new libsodium

* Wed Oct 11 2023 daviddavid <daviddavid> 3.2-4.mga10
+ Revision: 1994345
- rebuild for icu73

* Sat Jan 07 2023 squidf <squidf> 3.2-3.mga9
+ Revision: 1931167
- Mass rebuild for icu 72.1

* Thu Oct 13 2022 papoteur <papoteur> 3.2-2.mga9
+ Revision: 1896742
- Rebuild for libfmt 9.1.0

* Sun Jun 19 2022 wally <wally> 3.2-1.mga9
+ Revision: 1865174
- new version 3.2
- build using system doctest, fmt, libstemmer, xxhash and zstd
- use system wide default crypto ciphers
- rebuild for openssl 3.0.0
+ squidf <squidf>
- rebuild for icu 71.1
+ umeabot <umeabot>
- Mageia 9 Mass Rebuild

* Wed Aug 04 2021 luigiwalser <luigiwalser> 2.7-3.mga9
+ Revision: 1739304
- rebuild for icu

* Sat Mar 27 2021 wally <wally> 2.7-2.mga9
+ Revision: 1710827
- fix armv7hl build

* Sat Mar 27 2021 wally <wally> 2.7-1.mga9
+ Revision: 1710820
- new version 2.7

* Mon Nov 30 2020 luigiwalser <luigiwalser> 2.5-2.mga8
+ Revision: 1650927
- rebuild for icu

* Sat Jul 11 2020 daviddavid <daviddavid> 2.5-1.mga8
+ Revision: 1604393
- new version: 2.5
+ wally <wally>
- rebuild for icu 67.1

* Sat Apr 04 2020 wally <wally> 2.3-3.mga8
+ Revision: 1564500
- rebuild for new icu 66.1

* Mon Feb 17 2020 umeabot <umeabot> 2.3-2.mga8
+ Revision: 1537520
- Mageia 8 Mass Rebuild

* Wed Feb 12 2020 shlomif <shlomif> 2.3-1.mga8
+ Revision: 1506299
- New version 2.3

* Sun Nov 03 2019 daviddavid <daviddavid> 1.9.4-6.mga8
+ Revision: 1457418
- fix user and group in tmpfile conf

* Sun Nov 03 2019 daviddavid <daviddavid> 1.9.4-5.mga8
+ Revision: 1457405
- add a tmpfile conf file and fix the service file (mga#25628)
- enhance the postrotate script (mga#25628)

* Mon Oct 28 2019 daviddavid <daviddavid> 1.9.4-4.mga8
+ Revision: 1456311
- switch tmpfile dir from /var/run to /run/rspamd

* Sat Oct 05 2019 daviddavid <daviddavid> 1.9.4-3.mga8
+ Revision: 1449500
- rebuild for new icu 65.1

* Sat Jun 08 2019 shlomif <shlomif> 1.9.4-2.mga7
+ Revision: 1399686
- Release build.

* Fri Jun 07 2019 shlomif <shlomif> 1.9.4-1.mga7
+ Revision: 1399679
- New version 1.9.4
- New version 1.9.2

* Thu Feb 14 2019 shlomif <shlomif> 1.8.3-1.mga7
+ Revision: 1366903
- New version 1.8.2

* Fri Jan 11 2019 daviddavid <daviddavid> 1.8.2-2.mga7
+ Revision: 1354832
- rebuild for new icu

* Thu Nov 22 2018 shlomif <shlomif> 1.8.2-1.mga7
+ Revision: 1333298
- New version 1.8.2

* Wed Sep 12 2018 shlomif <shlomif> 1.7.9-1.mga7
+ Revision: 1258743
- New version 1.7.9

* Tue Aug 28 2018 daviddavid <daviddavid> 1.6.2-5.mga7
+ Revision: 1255141
- rebuild for new icu

* Fri Dec 29 2017 wally <wally> 1.6.2-4.mga7
+ Revision: 1187012
- rebuild for new icu

* Mon Dec 18 2017 wally <wally> 1.6.2-3.mga7
+ Revision: 1183241
- build with gmime2.6

* Sat Aug 26 2017 guillomovitch <guillomovitch> 1.6.2-2.mga7
+ Revision: 1148136
- rebuild for latest openssl

* Wed Jul 19 2017 shlomif <shlomif> 1.6.2-1.mga7
+ Revision: 1125396
- fix path
- Importing based on the upstream built-in centos .spec


* Thu Sep 17 2015 Vsevolod Stakhov <vsevolod-at-highsecure.ru> 1.0.0-1
- Update to 1.0.0

* Fri May 29 2015 Vsevolod Stakhov <vsevolod-at-highsecure.ru> 0.9.9-1
- Update to 0.9.9

* Thu May 21 2015 Vsevolod Stakhov <vsevolod-at-highsecure.ru> 0.9.4-1
- Update to 0.9.4

* Tue May 19 2015 Vsevolod Stakhov <vsevolod-at-highsecure.ru> 0.9.3-1
- Update to 0.9.3

* Tue May 19 2015 Vsevolod Stakhov <vsevolod-at-highsecure.ru> 0.9.2-1
- Update to 0.9.2

* Sun May 17 2015 Vsevolod Stakhov <vsevolod-at-highsecure.ru> 0.9.1-1
- Update to 0.9.1

* Wed May 13 2015 Vsevolod Stakhov <vsevolod-at-highsecure.ru> 0.9.0-1
- Update to 0.9.0

* Fri Mar 13 2015 Vsevolod Stakhov <vsevolod-at-highsecure.ru> 0.8.3-1
- Update to 0.8.3

* Tue Mar 10 2015 Vsevolod Stakhov <vsevolod-at-highsecure.ru> 0.8.2-1
- Update to 0.8.2

* Fri Jan 23 2015 Vsevolod Stakhov <vsevolod-at-highsecure.ru> 0.8.1-1
- Update to 0.8.1

* Fri Jan 02 2015 Vsevolod Stakhov <vsevolod-at-highsecure.ru> 0.8.0-1
- Update to 0.8.0

* Mon Nov 24 2014 Vsevolod Stakhov <vsevolod-at-highsecure.ru> 0.7.6-1
- Update to 0.7.6

* Mon Nov 17 2014 Vsevolod Stakhov <vsevolod-at-highsecure.ru> 0.7.5-1
- Update to 0.7.5

* Sat Nov 08 2014 Vsevolod Stakhov <vsevolod-at-highsecure.ru> 0.7.4-1
- Update to 0.7.4

* Mon Nov 03 2014 Vsevolod Stakhov <vsevolod-at-highsecure.ru> 0.7.3-1
- Update to 0.7.3

* Wed Oct 15 2014 Vsevolod Stakhov <vsevolod-at-highsecure.ru> 0.7.2-1
- Update to 0.7.2

* Tue Sep 30 2014 Vsevolod Stakhov <vsevolod-at-highsecure.ru> 0.7.1-1
- Update to 0.7.1

* Mon Sep 1 2014 Vsevolod Stakhov <vsevolod-at-highsecure.ru> 0.7.0-1
- Update to 0.7.0

* Fri Jan 10 2014 Vsevolod Stakhov <vsevolod-at-highsecure.ru> 0.6.7-1
- Update to 0.6.7.

* Fri Dec 27 2013 Vsevolod Stakhov <vsevolod-at-highsecure.ru> 0.6.6-1
- Update to 0.6.6.

* Fri Dec 20 2013 Vsevolod Stakhov <vsevolod-at-highsecure.ru> 0.6.5-1
- Update to 0.6.5.

* Wed Dec 18 2013 Vsevolod Stakhov <vsevolod-at-highsecure.ru> 0.6.4-1
- Update to 0.6.4.

* Tue Dec 10 2013 Vsevolod Stakhov <vsevolod-at-highsecure.ru> 0.6.3-1
- Update to 0.6.3.

* Fri Dec 06 2013 Vsevolod Stakhov <vsevolod-at-highsecure.ru> 0.6.2-1
- Update to 0.6.2.

* Tue Nov 19 2013 Vsevolod Stakhov <vsevolod-at-highsecure.ru> 0.6.0-1
- Update to 0.6.0.

* Mon Jun 10 2013 Vsevolod Stakhov <vsevolod-at-highsecure.ru> 0.5.6-1
- Update to 0.5.6.

* Sat May 25 2013 Vsevolod Stakhov <vsevolod-at-highsecure.ru> 0.5.5-1
- Initial spec version.
